@@ -10,37 +10,6 @@ def basic_case_dir(testdir):
     return case_dir
 
 
-def test_assert_match_without_setting_snapshot_dir(testdir, basic_case_dir):
-    testdir.makepyfile("""
-        def test_sth(snapshot):
-            snapshot.assert_match(u'the value of snapshot1.txt', 'snapshot1.txt')
-    """)
-    result = testdir.runpytest('-v')
-    result.stdout.fnmatch_lines([
-        '*::test_sth FAILED*',
-        "E* AssertionError: snapshot.snapshot_dir was not set.",
-    ])
-    assert result.ret == 1
-
-
-def test_assert_match_auto_setting_snapshot_dir(testdir, basic_case_dir):
-    """
-    Test that when using paths as snapshot names,
-    if the snapshot_dir is not already set, it is set to the snapshot's parent.
-    """
-    testdir.makepyfile("""
-        try:
-            from pathlib import Path
-        except ImportError:
-            from pathlib2 import Path
-
-        def test_sth(snapshot):
-            snapshot.assert_match(u'the value of snapshot1.txt', Path('case_dir/snapshot1.txt'))
-            assert snapshot.snapshot_dir == Path('case_dir').absolute()
-    """)
-    assert_pytest_passes(testdir)
-
-
 def test_assert_match_with_external_snapshot_path(testdir, basic_case_dir):
     testdir.makepyfile("""
         try:
@@ -55,7 +24,7 @@ def test_assert_match_with_external_snapshot_path(testdir, basic_case_dir):
     result = testdir.runpytest('-v')
     result.stdout.fnmatch_lines([
         '*::test_sth FAILED*',
-        "E* AssertionError: Snapshot path not_case_dir*snapshot1.txt is not in case_dir",
+        "E* AssertionError: Snapshot path not_case_dir?snapshot1.txt is not in case_dir",
     ])
     assert result.ret == 1
 
@@ -79,7 +48,7 @@ def test_assert_match_failure(testdir, basic_case_dir):
     result.stdout.fnmatch_lines([
         '*::test_sth FAILED*',
         ">* raise AssertionError(snapshot_diff_msg)",
-        'E* AssertionError: value does not match the expected value in snapshot case_dir*snapshot1.txt',
+        'E* AssertionError: value does not match the expected value in snapshot case_dir?snapshot1.txt',
         "E* assert * == *",
         "E* - the value of snapshot1.txt",
         "E* + the INCORRECT value of snapshot1.txt",
@@ -97,7 +66,7 @@ def test_assert_match_missing_snapshot(testdir, basic_case_dir):
     result = testdir.runpytest('-v')
     result.stdout.fnmatch_lines([
         '*::test_sth FAILED*',
-        "E* snapshot case_dir*snapshot_that_doesnt_exist.txt doesn't exist. "
+        "E* snapshot case_dir?snapshot_that_doesnt_exist.txt doesn't exist. "
         "(run pytest with --snapshot-update to create it)",
     ])
     assert result.ret == 1
@@ -177,13 +146,34 @@ def test_assert_match_create_new_snapshot(testdir, basic_case_dir):
         '*::test_sth ERROR*',
         "E* Snapshot directory was modified: case_dir",
         'E*   Created snapshots:',
-        'E*     sub_dir*new_snapshot1.txt',
+        'E*     sub_dir?new_snapshot1.txt',
     ])
     assert result.ret == 1
 
     assert_pytest_passes(testdir)  # assert that snapshot update worked
 
 
+def test_assert_match_create_new_snapshot_in_default_dir(testdir):
+    testdir.makepyfile("""
+        def test_sth(snapshot):
+            snapshot.assert_match(u'the value of new_snapshot1.txt', 'sub_dir/new_snapshot1.txt')
+    """)
+    result = testdir.runpytest('-v', '--snapshot-update')
+    result.stdout.fnmatch_lines([
+        '*::test_sth PASSED*',
+        '*::test_sth ERROR*',
+        "E* Snapshot directory was modified: snapshots?test_assert_match_create_new_snapshot_in_default_dir?test_sth",
+        'E*   Created snapshots:',
+        'E*     sub_dir?new_snapshot1.txt',
+    ])
+    assert result.ret == 1
+    assert testdir.tmpdir.join(
+        'snapshots/test_assert_match_create_new_snapshot_in_default_dir/test_sth/sub_dir/new_snapshot1.txt'
+    ).read_text('utf-8') == u'the value of new_snapshot1.txt'
+
+    assert_pytest_passes(testdir)  # assert that snapshot update worked
+
+
 def test_assert_match_existing_snapshot_is_not_file(testdir, basic_case_dir):
     basic_case_dir.mkdir('directory1')
     testdir.makepyfile("""
@@ -194,6 +184,6 @@ def test_assert_match_existing_snapshot_is_not_file(testdir, basic_case_dir):
     result = testdir.runpytest('-v', '--snapshot-update')
     result.stdout.fnmatch_lines([
         '*::test_sth FAILED*',
-        "E* AssertionError: snapshot exists but is not a file: case_dir*directory1",
+        "E* AssertionError: snapshot exists but is not a file: case_dir?directory1",
     ])
     assert result.ret == 1
